@@ -1,17 +1,14 @@
 #define banner  \
-"bg5conv (CJK ver. 4.8.1)" \
+"bg5conv (CJK ver. 4.8.5)" \
 
 /*2:*/
-#line 94 "/home/wl/git/cjk/cjk-4.8.1/utils/Bg5conv/bg5conv.w"
+#line 94 "/home/wl/git/cjk/cjk-4.8.5/utils/Bg5conv/bg5conv.w"
 
 #include <stdio.h> 
 #include <stdlib.h> 
 
 
-int main(argc,argv)
-int argc;
-char*argv[];
-
+int main(int argc,char*argv[])
 {int ch;
 
 fprintf(stdout,"\\def\\CJKpreproc{%s}",banner);
