@@ -1,18 +1,15 @@
 #define banner  \
-"cefconv (CJK ver. 4.8.1)" \
+"cefconv (CJK ver. 4.8.5)" \
 
 /*2:*/
-#line 100 "/home/wl/git/cjk/cjk-4.8.1/utils/CEFconv/cefconv.w"
+#line 100 "/home/wl/git/cjk/cjk-4.8.5/utils/CEFconv/cefconv.w"
 
 #include <ctype.h> 
 #include <stdio.h> 
 #include <stdlib.h> 
 
 
-int main(argc,argv)
-int argc;
-char*argv[];
-
+int main(int argc,char*argv[])
 {int ch,i;
 unsigned char in[16];
 unsigned char out[32];
