@@ -1,18 +1,15 @@
 #define banner  \
-"cefsconv (CJK ver. 4.8.1)" \
+"cefsconv (CJK ver. 4.8.5)" \
 
 /*2:*/
-#line 108 "/home/wl/git/cjk/cjk-4.8.1/utils/CEFconv/cefsconv.w"
+#line 111 "/home/wl/git/cjk/cjk-4.8.5/utils/CEFconv/cefsconv.w"
 
 #include <ctype.h> 
 #include <stdio.h> 
 #include <stdlib.h> 
 
 
-int main(argc,argv)
-int argc;
-char*argv[];
-
+int main(int argc,char*argv[])
 {int ch,i;
 unsigned char in[16];
 unsigned char out[32];
@@ -72,6 +69,7 @@ goto no_macro;
 if(*inp!='-'||feof(stdin))
 goto no_macro;
 
+*(outp++)= '\177';
 *(outp++)= '\177';
 *(outp++)= '\"';
 *(outp++)= '0';
@@ -88,7 +86,6 @@ if(isxdigit(*inp)&&*inp<0x80&&!feof(stdin))
 else
 goto no_macro;
 
-*(outp++)= '\177';
 *(outp++)= '\177';
 *(outp++)= '\"';
 *(outp++)= '0';
