@@ -1,17 +1,14 @@
 #define banner  \
-"sjisconv (CJK ver. 4.8.1)" \
+"sjisconv (CJK ver. 4.8.5)" \
 
 /*2:*/
-#line 93 "/home/wl/git/cjk/cjk-4.8.1/utils/SJISconv/sjisconv.w"
+#line 96 "/home/wl/git/cjk/cjk-4.8.5/utils/SJISconv/sjisconv.w"
 
 #include <stdio.h> 
 #include <stdlib.h> 
 
 
-int main(argc,argv)
-int argc;
-char*argv[];
-
+int main(int argc,char*argv[])
 {int ch;
 
 fprintf(stdout,"\\def\\CJKpreproc{%s}",banner);
