@@ -1,17 +1,14 @@
 #define banner  \
-"extconv (CJK ver. 4.8.2)" \
+"extconv (CJK ver. 4.8.5)" \
 
 /*2:*/
-#line 94 "/home/wl/git/cjk/cjk-4.8.2/utils/extconv/extconv.w"
+#line 94 "/home/wl/git/cjk/cjk-4.8.5/utils/extconv/extconv.w"
 
 #include <stdio.h> 
 #include <stdlib.h> 
 
 
-int main(argc,argv)
-int argc;
-char*argv[];
-
+int main(int argc,char*argv[])
 {int ch;
 
 
