@@ -1,5 +1,5 @@
 #define banner  \
-"hbf2gf (CJK ver. 4.8.1)" \
+"hbf2gf (CJK ver. 4.8.5)" \
  \
 
 #define TRUE 1
@@ -100,11 +100,14 @@
 #define VALID_SUBCODE 1 \
 
 /*4:*/
-#line 193 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 191 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 /*10:*/
-#line 413 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 408 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
+#ifdef HAVE_CONFIG_H
+#include <c-auto.h> 
+#endif
 #include <ctype.h> 
 #include <stdio.h> 
 #include <stdlib.h> 
@@ -118,16 +121,10 @@
 
 
 /*:10*//*69:*/
-#line 2483 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 2473 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 #if defined(HAVE_LIBKPATHSEA)
-#ifdef VERY_OLD_KPATHSEA
-#include "kpathsea/proginit.h"
-#include "kpathsea/progname.h"
-#include "kpathsea/tex-glyph.h"
-#else
 #include "kpathsea/kpathsea.h"
-#endif
 
 #elif defined(HAVE_EMTEXDIR)
 #include "emtexdir.h"
@@ -137,47 +134,48 @@
 #endif
 
 /*:69*/
-#line 194 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 192 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 /*11:*/
-#line 431 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 429 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
-void write_file(void);
+static void write_file(void);
 
 
 /*:11*//*13:*/
-#line 493 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 491 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
-void write_pre(void);
+static void write_pre(void);
 
 
 /*:13*//*16:*/
-#line 581 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 579 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
-void write_data(void);
+static void write_data(void);
 
 
 /*:16*//*20:*/
-#line 692 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 690 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
-void write_post(void);
+static void write_post(void);
 
 
 /*:20*//*25:*/
-#line 836 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 834 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
-void fputl(long,FILE*);
+static void fputl(long,FILE*);
 
 
 /*:25*//*29:*/
-#line 999 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 994 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
-void make_pixel_array(void);
+static void make_pixel_array(void);
 
 
 /*:29*//*36:*/
-#line 1227 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 1222 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
+static
 #ifdef __GNUC__
 __inline__
 #endif
@@ -185,8 +183,9 @@ void read_row(unsigned char*);
 
 
 /*:36*//*39:*/
-#line 1279 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 1274 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
+static
 #ifdef __GNUC__
 __inline__
 #endif
@@ -194,75 +193,75 @@ void write_row(unsigned char*);
 
 
 /*:39*//*41:*/
-#line 1334 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 1329 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
-void write_coding(void);
+static void write_coding(void);
 
 
 /*:41*//*45:*/
-#line 1495 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 1490 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
-void write_pl(void);
+static void write_pl(void);
 
 
 /*:45*//*47:*/
-#line 1592 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 1587 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
-void write_ovp(void);
+static void write_ovp(void);
 
 
 /*:47*//*50:*/
-#line 1737 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 1732 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
-void write_job(void);
+static void write_job(void);
 
 
 /*:50*//*54:*/
-#line 1986 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 1981 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
-void read_config(void);
+static void read_config(void);
 
 
 /*:54*//*64:*/
-#line 2317 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 2312 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
-int fsearch(char*);
+static int fsearch(const char*);
 
 
 /*:64*//*67:*/
-#line 2457 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 2451 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
-void config_error(char*);
+static void config_error(const char*);
 
 
 /*:67*//*71:*/
-#line 2517 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 2494 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
-char*TeX_search_version(void);
+static const char*TeX_search_version(void);
 
 
 /*:71*//*74:*/
-#line 2552 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 2529 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 #ifdef HAVE_EMTEXDIR
 extern int setup_list(struct emtex_dir*,char*,const char*,unsigned);
-int dir_setup(struct emtex_dir*,const char*,const char*,unsigned);
-char*file_find(char*,struct emtex_dir*);
+static int dir_setup(struct emtex_dir*,const char*,const char*,unsigned);
+static char*file_find(char*,struct emtex_dir*);
 #endif
 
 
 /*:74*//*79:*/
-#line 2649 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 2621 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
-char*TeX_search_cfg_file(char*);
-char*TeX_search_hbf_file(char*);
+static char*TeX_search_cfg_file(char*);
+static char*TeX_search_hbf_file(char*);
 
 
 /*:79*/
-#line 195 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 193 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 /*2:*/
-#line 129 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 127 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 int nmb_files= -1;
 int unicode= FALSE;
@@ -303,7 +302,7 @@ int end_of_file= FALSE;
 
 
 /*:2*//*15:*/
-#line 540 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 538 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 long char_adr[256];
 long*char_adr_p;
@@ -345,7 +344,7 @@ int dot_count;
 
 
 /*:15*//*19:*/
-#line 669 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 667 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 char coding[STRING_LENGTH+1];
 char comment[STRING_LENGTH+1];
@@ -364,12 +363,12 @@ double ppp_y;
 
 
 /*:19*//*27:*/
-#line 876 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 871 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 HBF_CHAR code;
 const unsigned char*bitmap;
 
-unsigned char*bP;
+const unsigned char*bP;
 
 unsigned char out_char[MAX_CHAR_SIZE*MAX_CHAR_SIZE+1];
 
@@ -387,13 +386,13 @@ long s_mag_x,s_mag_y,s_slant;
 
 
 /*:27*//*38:*/
-#line 1274 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 1269 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 int threshold= 128;
 
 
 /*:38*//*49:*/
-#line 1726 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 1721 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 char job_extension[EXTENSION_LENGTH+1];
 char rm_command[STRING_LENGTH+1];
@@ -405,13 +404,13 @@ int ofm_file= FALSE;
 
 
 /*:49*//*53:*/
-#line 1981 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 1976 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 char Buffer[STRING_LENGTH+1];
 
 
 /*:53*//*58:*/
-#line 2099 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 2094 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 int offset_x;
 int offset_y;
@@ -420,13 +419,13 @@ HBF_CHAR user_min_char;
 int have_min_char= FALSE;
 
 /*:58*//*60:*/
-#line 2256 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 2251 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 HBF_CHAR min_char,max_char;
 
 
 /*:60*//*62:*/
-#line 2283 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 2278 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 char b2_codes[256];
 unsigned char min_2_byte,max_2_byte;
@@ -434,16 +433,9 @@ int nmb_2_bytes= 0;
 
 
 /*:62*//*70:*/
-#line 2501 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 2485 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
-#if defined(HAVE_LIBKPATHSEA)
-#ifdef KPSEDLL
-
-extern KPSEDLL char*kpathsea_version_string;
-#else
-extern DllImport char*kpathsea_version_string;
-#endif
-#elif defined(HAVE_EMTEXDIR)
+#if defined(HAVE_EMTEXDIR)
 char emtex_version_string[]= "emTeXdir";
 #elif !defined(HAVE_MIKTEX)
 char no_version_string[]= "no search library";
@@ -451,7 +443,7 @@ char no_version_string[]= "no search library";
 
 
 /*:70*//*73:*/
-#line 2545 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 2522 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 #ifdef HAVE_EMTEXDIR
 struct emtex_dir cfg_path,hbf_path;
@@ -459,37 +451,27 @@ struct emtex_dir cfg_path,hbf_path;
 
 
 /*:73*//*76:*/
-#line 2591 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 2569 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
+#ifdef HAVE_EMTEXDIR
 char name_buffer[FILE_NAME_LENGTH+1];
+#endif
 
 
 /*:76*/
-#line 196 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 194 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 
 
-int main(argc,argv)
-int argc;
-char*argv[];
-
+int main(int argc,char*argv[])
 {char*p;
 
 /*78:*/
-#line 2613 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 2594 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 #if defined(HAVE_LIBKPATHSEA)
-#ifdef OLD_KPATHSEA
-kpse_set_progname(argv[0]);
-#else
 kpse_set_program_name(argv[0],"hbf2gf");
-#endif
-
-#ifdef VERY_OLD_KPATHSEA
-kpse_init_prog("HBF2GF",300,"cx",true,"cmr10");
-#else
 kpse_init_prog("HBF2GF",300,"cx","cmr10");
-#endif
 
 #elif defined(HAVE_EMTEXDIR)
 if(!dir_setup(&cfg_path,"HBFCFG",NULL,EDS_BANG))
@@ -506,16 +488,16 @@ exit(1);
 
 
 /*:78*/
-#line 205 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 200 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 
 /*7:*/
-#line 312 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 307 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 if(argc==2)
 {if(strcmp(argv[1],"--help")==0)
 /*6:*/
-#line 293 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 288 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 {printf(USAGE);
 exit(0);
@@ -523,11 +505,11 @@ exit(0);
 
 
 /*:6*/
-#line 315 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 310 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 else if(strcmp(argv[1],"--version")==0)
 /*5:*/
-#line 266 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 261 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 {printf("\n");
 printf(banner);
@@ -538,7 +520,7 @@ exit(0);
 
 
 /*:5*/
-#line 317 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 312 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 }
 
@@ -576,7 +558,7 @@ exit(1);
 
 
 /*:7*/
-#line 207 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 202 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 
 if(!quiet)
@@ -605,7 +587,7 @@ read_config();
 
 if(mf_like)
 /*8:*/
-#line 357 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 352 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 {if(unicode)
 file_number= (int)strtol(&argv[1][strlen(argv[1])-2],
@@ -633,11 +615,11 @@ y_scale= (double)x_resolution/y_scale;
 
 
 /*:8*/
-#line 234 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 229 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 
 /*28:*/
-#line 908 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 903 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 {int col,offset;
 
@@ -720,11 +702,11 @@ s_slant= slant*SCALE;
 
 
 /*:28*/
-#line 236 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 231 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 
 /*9:*/
-#line 392 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 387 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 {int j,max_numb;
 
@@ -746,7 +728,7 @@ nmb_files= j;
 
 
 /*:9*/
-#line 238 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 233 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 
 if(tfm_files)
@@ -764,9 +746,9 @@ return 0;
 
 
 /*:4*//*12:*/
-#line 439 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 437 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
-void write_file(void)
+static void write_file(void)
 {char output_file[FILE_NAME_LENGTH+1];
 
 
@@ -808,9 +790,9 @@ write_data();
 
 
 /*:12*//*14:*/
-#line 500 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 498 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
-void write_pre(void)
+static void write_pre(void)
 {char out_s[40],s[20];
 time_t secs_now;
 struct tm*time_now;
@@ -831,15 +813,15 @@ fputs(out_s,out);
 
 
 /*:14*//*17:*/
-#line 586 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 584 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
-void write_data(void)
+static void write_data(void)
 {dot_count= 0;
 char_adr_p= char_adr;
 
 for(last_char= 0;(last_char<256)&&!end_of_file;last_char++)
 /*18:*/
-#line 611 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 609 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 {if(dot_count++%10==0)
 if(pk_files&&!quiet)
@@ -883,15 +865,15 @@ fputc(EOC,out);
 
 
 /*:18*/
-#line 592 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 590 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 }
 
 
 /*:17*//*21:*/
-#line 697 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 695 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
-void write_post(void)
+static void write_post(void)
 {long special_adr;
 long post_adr;
 
@@ -917,7 +899,7 @@ tfm_width= (tfm_output_size_x+2*tfm_offset_x)*_2_20;
 
 
 /*22:*/
-#line 743 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 741 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 special_adr= ftell(out);
 
@@ -935,10 +917,10 @@ fputs(comment,out);
 
 
 /*:22*/
-#line 723 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 721 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 /*23:*/
-#line 772 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 770 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 post_adr= ftell(out);
 fputc(POST,out);
@@ -977,10 +959,10 @@ fputl(*char_adr_p++,out);
 
 
 /*:23*/
-#line 724 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 722 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 /*24:*/
-#line 823 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 821 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 fputc(POSTPOST,out);
 fputl(post_adr,out);
@@ -992,18 +974,15 @@ fputc(POSTPOST_ID,out);
 
 
 /*:24*/
-#line 725 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 723 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 }
 
 
 /*:21*//*26:*/
-#line 841 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
-
-void fputl(num,f)
-long num;
-FILE*f;
+#line 839 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
+static void fputl(long num,FILE*f)
 {fputc(num>>24,f);
 fputc(num>>16,f);
 fputc(num>>8,f);
@@ -1012,9 +991,9 @@ fputc(num,f);
 
 
 /*:26*//*30:*/
-#line 1004 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 999 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
-void make_pixel_array(void)
+static void make_pixel_array(void)
 {unsigned char*prP;
 unsigned char*temp_prP;
 unsigned char*new_prP;
@@ -1043,14 +1022,14 @@ again:
 if(b2_codes[code&0xFF])
 {if(pk_files)
 {bitmap= hbfGetBitmap(hbf,code);
-bP= (unsigned char*)bitmap;
+bP= bitmap;
 
 
 if(!bitmap)
 empty_char= TRUE;
 else
 /*31:*/
-#line 1063 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 1058 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 {if(pk_output_size_y==input_size_y)
 temp_prP= prP;
@@ -1058,7 +1037,7 @@ temp_prP= prP;
 curr_row= input_size_y-1;
 for(row= 0;row<pk_output_size_y;++row)
 {/*32:*/
-#line 1077 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 1072 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 if(pk_output_size_y==input_size_y)
 
@@ -1080,7 +1059,7 @@ need_to_read_row= 1;
 }
 
 /*33:*/
-#line 1104 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 1099 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 if(need_to_read_row)
 if(rows_read<input_size_y)
@@ -1112,16 +1091,16 @@ frac_row_to_fill= SCALE;
 
 
 /*:33*/
-#line 1097 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 1092 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 }
 
 
 /*:32*/
-#line 1069 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 1064 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 /*34:*/
-#line 1145 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 1140 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 if(pk_width==input_size_x&&s_slant==0)
 
@@ -1176,7 +1155,7 @@ frac_col_to_fill-= frac_col_left;
 }
 
 /*35:*/
-#line 1203 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 1198 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 if(frac_col_to_fill> 0)
 {--xP;
@@ -1196,20 +1175,20 @@ write_row(new_prP);
 
 
 /*:35*/
-#line 1198 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 1193 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 }
 
 
 /*:34*/
-#line 1071 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 1066 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 }
 }
 
 
 /*:31*/
-#line 1040 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 1035 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 }
 }
@@ -1233,14 +1212,13 @@ goto again;
 
 
 /*:30*//*37:*/
-#line 1235 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 1231 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
+static
 #ifdef __GNUC__
 __inline__
 #endif
-void read_row(pixelrow)
-unsigned char*pixelrow;
-
+void read_row(unsigned char*pixelrow)
 {register int col,bitshift,offset;
 register unsigned char*xP;
 register unsigned char item= 0;
@@ -1248,7 +1226,7 @@ register unsigned char item= 0;
 if(rotation)
 {bitshift= 7-(curr_row%8);
 offset= (input_size_y+7)/8;
-bP= (unsigned char*)bitmap+curr_row/8;
+bP= bitmap+curr_row/8;
 for(col= 0,xP= pixelrow;col<input_size_x;++col,++xP)
 {*xP= ((*bP>>bitshift)&1)==1?PIXEL_MAXVAL:0;
 bP+= offset;
@@ -1270,14 +1248,13 @@ bitshift= 7;
 
 
 /*:37*//*40:*/
-#line 1287 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 1283 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
+static
 #ifdef __GNUC__
 __inline__
 #endif
-void write_row(pixelrow)
-unsigned char*pixelrow;
-
+void write_row(unsigned char*pixelrow)
 {register int col;
 register unsigned char*xP;
 
@@ -1288,9 +1265,9 @@ for(col= 0,xP= pixelrow;col<pk_output_size_x;++col,++xP)
 
 
 /*:40*//*42:*/
-#line 1342 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 1337 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
-void write_coding(void)
+static void write_coding(void)
 {register int count,skip;
 register unsigned char paint;
 register int x,y;
@@ -1305,7 +1282,7 @@ goto start;
 
 while(y<pk_output_size_y)
 {/*43:*/
-#line 1366 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 1361 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 count= 0;
 x= 0;
@@ -1374,11 +1351,11 @@ continue;
 
 
 /*:43*/
-#line 1357 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 1352 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 start:
 /*44:*/
-#line 1434 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 1429 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 while(x<pk_output_size_x)
 {if(*cp==paint)
@@ -1419,7 +1396,7 @@ paint= WHITE;
 
 
 /*:44*/
-#line 1359 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 1354 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 y++;
 }
@@ -1427,9 +1404,9 @@ y++;
 
 
 /*:42*//*46:*/
-#line 1500 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 1495 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
-void write_pl(void)
+static void write_pl(void)
 {int i,pos;
 char output_file[FILE_NAME_LENGTH+1];
 long t,sc;
@@ -1517,9 +1494,9 @@ fclose(out);
 
 
 /*:46*//*48:*/
-#line 1597 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 1592 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
-void write_ovp(void)
+static void write_ovp(void)
 {int c,i,nmb_subfonts,remainder,count,pos;
 char output_file[FILE_NAME_LENGTH+1];
 long t,sc;
@@ -1632,9 +1609,9 @@ fclose(out);
 
 
 /*:48*//*51:*/
-#line 1742 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 1737 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
-void write_job(void)
+static void write_job(void)
 {FILE*out;
 int i,j;
 char buffer[FILE_NAME_LENGTH+1];
@@ -1718,15 +1695,15 @@ fclose(out);
 
 
 /*:51*//*55:*/
-#line 1994 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 1989 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
-void read_config(void)
+static void read_config(void)
 {HBF_BBOX*boxp;
 char*real_config_file;
 
 
 /*56:*/
-#line 2046 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 2041 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 {int i,lastext= -1;
 
@@ -1744,7 +1721,7 @@ strcat(config_file,".cfg");
 
 
 /*:56*/
-#line 2000 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 1995 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 
 real_config_file= TeX_search_cfg_file(config_file);
@@ -1779,7 +1756,7 @@ exit(0);
 }
 
 /*57:*/
-#line 2063 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 2058 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 {char hbf_header[STRING_LENGTH+1];
 char*real_hbf_header;
@@ -1816,10 +1793,10 @@ strcpy(output_name,Buffer);
 
 
 /*:57*/
-#line 2033 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 2028 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 /*59:*/
-#line 2107 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 2102 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 {if(fsearch("nmb_files"))
 nmb_files= atoi(Buffer);
@@ -1961,11 +1938,11 @@ job_extension[EXTENSION_LENGTH]= '\0';
 
 
 /*:59*/
-#line 2034 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 2029 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 
 /*61:*/
-#line 2261 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 2256 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 {const void*cp;
 HBF_CHAR dummy;
@@ -1980,10 +1957,10 @@ min_char= user_min_char;
 
 
 /*:61*/
-#line 2036 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 2031 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 /*63:*/
-#line 2290 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 2285 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 {const void*b2r;
 unsigned char dummy;
@@ -2006,7 +1983,7 @@ nmb_2_bytes++;
 
 
 /*:63*/
-#line 2037 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 2032 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 
 fclose(config);
@@ -2014,12 +1991,11 @@ fclose(config);
 
 
 /*:55*//*65:*/
-#line 2322 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
-
-int fsearch(search_string)
-char*search_string;
+#line 2317 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
+static int fsearch(const char*search_string)
 {char*P,p;
+const char*Q;
 char temp_buffer[STRING_LENGTH+1];
 char env_name[STRING_LENGTH+1];
 char*env_p;
@@ -2031,8 +2007,8 @@ int count= STRING_LENGTH;
 rewind(config);
 
 do
-{P= search_string;
-p= tolower(*P);
+{Q= search_string;
+p= tolower((unsigned char)*Q);
 Ch= fgetc(config);
 ch= tolower(Ch);
 while(!(ch==p&&old_ch=='\n')&&Ch!=EOF)
@@ -2044,12 +2020,12 @@ ch= tolower(Ch);
 }
 
 for(;;)
-{if(*(++P)=='\0')
+{if(*(++Q)=='\0')
 if((Ch= fgetc(config))==' '||Ch=='\t')
 
 goto success;
 Ch= fgetc(config);
-if(tolower(Ch)!=tolower(*P))
+if(tolower(Ch)!=tolower((unsigned char)*Q))
 break;
 }
 }
@@ -2071,7 +2047,7 @@ Ch= fgetc(config);
 
 if(*temp_buffer)
 /*66:*/
-#line 2402 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 2396 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 {P= temp_buffer;
 Buf_p= Buffer;
@@ -2089,14 +2065,14 @@ continue;
 }
 while(*P=='{')
 P++;
-if(!(isalpha(*P)||*P=='_'))
+if(!(isalpha((unsigned char)*P)||*P=='_'))
 {fprintf(stderr,
 "Invalid environment variable name in configuration file\n");
 exit(1);
 }
 *(env_p++)= *(P++);
 while(*P)
-{if(isalnum(*P)||*P=='_')
+{if(isalnum((unsigned char)*P)||*P=='_')
 *(env_p++)= *(P++);
 else
 {while(*P=='}')
@@ -2124,7 +2100,7 @@ count--;
 
 
 /*:66*/
-#line 2377 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 2371 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 else
 *Buffer= '\0';
@@ -2134,11 +2110,9 @@ return(*Buffer)?1:0;
 
 
 /*:65*//*68:*/
-#line 2462 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
-
-void config_error(message)
-char*message;
+#line 2456 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
+static void config_error(const char*message)
 {fprintf(stderr,"Couldn't find `%s' entry in configuration file\n",
 message);
 exit(1);
@@ -2147,9 +2121,9 @@ exit(1);
 
 
 /*:68*//*72:*/
-#line 2522 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 2499 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
-char*TeX_search_version(void)
+static const char*TeX_search_version(void)
 {
 #if defined(HAVE_LIBKPATHSEA)
 return kpathsea_version_string;
@@ -2169,10 +2143,10 @@ return no_version_string;
 
 
 /*:72*//*75:*/
-#line 2564 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 2541 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 #ifdef HAVE_EMTEXDIR
-int dir_setup(ed,env,dir,flags)
+static int dir_setup(ed,env,dir,flags)
 struct emtex_dir*ed;
 const char*env;
 const char*dir;
@@ -2194,12 +2168,14 @@ env);
 
 return TRUE;
 }
+#endif
 
 
 /*:75*//*77:*/
-#line 2596 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 2576 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
-char*file_find(name,list)
+#ifdef HAVE_EMTEXDIR
+static char*file_find(name,list)
 char*name;
 struct emtex_dir*list;
 
@@ -2212,56 +2188,34 @@ return NULL;
 
 
 /*:77*//*80:*/
-#line 2655 "/home/wl/git/cjk/cjk-4.8.1/utils/hbf2gf/hbf2gf.w"
+#line 2627 "/home/wl/git/cjk/cjk-4.8.5/utils/hbf2gf/hbf2gf.w"
 
 #if defined(HAVE_LIBKPATHSEA)
-char*TeX_search_cfg_file(name)
-char*name;
-
+static char*TeX_search_cfg_file(char*name)
 {
-#ifdef OLD_KPATHSEA
-return kpse_find_file(name,kpse_dvips_config_format,TRUE);
-#else
 return kpse_find_file(name,kpse_program_text_format,TRUE);
-#endif
 }
 
 
-char*TeX_search_hbf_file(name)
-char*name;
-
+static char*TeX_search_hbf_file(char*name)
 {
-#ifdef VERY_OLD_KPATHSEA
-return kpse_find_file(name,kpse_dvips_header_format,TRUE);
-#else
-#ifndef KPSEDLL
-return kpse_find_file(name,kpse_type1_format,TRUE);
-#else
 return kpse_find_file(name,kpse_miscfonts_format,TRUE);
-#endif
-#endif
 }
 
 
 #elif defined(HAVE_EMTEXDIR)
-char*TeX_search_cfg_file(name)
-char*name;
-
+static char*TeX_search_cfg_file(char*name)
 {return file_find(name,&cfg_path);
 }
 
 
-char*TeX_search_hbf_file(name)
-char*name;
-
+static char*TeX_search_hbf_file(char*name)
 {return file_find(name,&hbf_path);
 }
 
 
 #elif defined(HAVE_MIKTEX)
-char*TeX_search_cfg_file(name)
-char*name;
-
+static char*TeX_search_cfg_file(char*name)
 {char result[_MAX_PATH];
 
 if(!miktex_find_input_file("hbf2gf",*name,result))
@@ -2270,9 +2224,7 @@ return strdup(result);
 }
 
 
-char*TeX_search_hbf_file(name)
-char*name;
-
+static char*TeX_search_hbf_file(char*name)
 {char result[_MAX_PATH];
 
 
@@ -2283,16 +2235,12 @@ return strdup(result);
 
 
 #else
-char*TeX_search_cfg_file(name)
-char*name;
-
+static char*TeX_search_cfg_file(char*name)
 {return name;
 }
 
 
-char*TeX_search_hbf_file(name)
-char*name;
-
+static char*TeX_search_hbf_file(char*name)
 {return name;
 }
 #endif
