@@ -4,6 +4,7 @@
 
 ;; Author: Kenichi HANDA <handa@etl.go.jp>
 ;;         Werner LEMBERG <wl@gnu.org>
+;;         Hin-Tak Leung <htl10@users.sourceforge.net>
 
 ;; Keywords: CJK package, LaTeX2e, emacs, xemacs
 
@@ -22,7 +23,7 @@
 ;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 
 ;;
-;; CJK Version 4.8.1 (10-Aug-2008)
+;; CJK Version 4.8.5 (16-Oct-2021)
 ;;
 
 ;;; Code
@@ -443,6 +444,7 @@
     (korean-ksc5601 . KS)
     (chinese-big5-1 . Bg5)
     (chinese-big5-2 . Bg5)
+    (big5 . Bg5)
     (chinese-cns11643-1 . CNS1)
     (chinese-cns11643-2 . CNS2)
     (chinese-cns11643-3 . CNS3)
@@ -504,6 +506,7 @@
     (chinese-gb2312    . ("\17767\177\177" . "\177%c\177%d\177"))
     (chinese-big5-1    . ("\17768\177\177" . "\177%c\177%d\177"))
     (chinese-big5-2    . ("\17768\177\177" . "\177%c\177%d\177"))
+    (big5              . ("\17768\177\177" . "\177%c\177%d\177"))
     (korean-ksc5601    . ("\17769\177\177" . "\177%c\177%d\177"))
 
     ;; Cdr part is a formatter string FORMAT.  Each character is
@@ -549,12 +552,44 @@
      "Coding-system for LaTeX2e CJK Package"
      '(mnemonic "CJK"
        pre-write-conversion cjk-encode))
-  (make-coding-system
-   'cjk-coding 0 ?c
-   "Coding-system for LaTeX2e CJK Package"
-   nil
-   '((pre-write-conversion . cjk-encode))))
-
+  (if (< emacs-major-version 23)
+      (make-coding-system
+       'cjk-coding 0 ?c
+       "Coding-system for LaTeX2e CJK Package"
+       nil
+       '((pre-write-conversion . cjk-encode)))
+    (define-coding-system
+      'cjk-coding
+      "Coding-system for LaTeX2e CJK Package"
+      :mnemonic ?c
+      :coding-type 'emacs-mule
+      :default-char ?
+      :charset-list '(ascii
+                      latin-iso8859-1
+                      latin-iso8859-2
+                      latin-iso8859-3
+                      latin-iso8859-4
+                      cyrillic-iso8859-5
+                      greek-iso8859-7
+                      thai-tis620
+                      vietnamese-viscii-lower
+                      vietnamese-viscii-upper
+                      latin-jisx0201
+                      katakana-jisx0201
+                      japanese-jisx0208
+                      japanese-jisx0212
+                      korean-ksc5601
+                      chinese-gb2312
+                      chinese-big5-1
+                      chinese-big5-2
+                      chinese-cns11643-1
+                      chinese-cns11643-2
+                      chinese-cns11643-3
+                      chinese-cns11643-4
+                      chinese-cns11643-5
+                      chinese-cns11643-6
+                      chinese-cns11643-7)
+      :pre-write-conversion 'cjk-encode)))
 
 ;; XEmacs doesn't have set-buffer-multibyte.
 ;;
@@ -596,17 +631,54 @@
           ch ch1 ch2
           format-spec
           (skipped-whitespace nil)
-          (last-pos 0))
+          (last-pos 0)
+          (unsupported-charset-warned nil))
       ;; Now we go to beginning of TEMP-BUF and start the loop.
       (goto-char (point-min))
       (setq prev-charset 'ascii)
 
       (while (not (eobp))
+        ;; In emacs 23+, the `charset' property holds the original
+        ;; encoding value; in emacs 22 and earlier, we get `nil'.
+        (setq tpch (get-text-property (point) 'charset))
         (setq ch (following-char))
         (set-buffer work-buf)
 
         ;; Set CHARSET to the character set of the current character.
-        (setq charset (char-charset ch))
+        ;; Use text property in preference to `char-charset'.
+        (if (not (eq tpch nil))
+            (setq charset tpch)
+          (setq charset (char-charset ch)))
+
+        ;; Avoid `tis620-2533' (new with emacs 23+); we replace it with
+        ;; Thai and ASCII (as a new optional argument to
+        ;; `char-charset'.
+        (if (eq charset 'tis620-2533)
+            (setq charset (char-charset ch '(thai-tis620 ascii))))
+
+        ;; emacs 25+: Language-detection heuristics changed.
+        ;; `big5' is preferred over `chinese-big5-1' and `chinese-big5-1'.
+        ;; If not overridden, can also swallow LaTeX (ascii) instructions
+        ;; afterwards.
+        (if (eq charset 'big5)
+            (setq charset (char-charset ch '(ascii big5))))
+
+        ;; Check whether we have Unicode based input.
+        (if (eq charset 'unicode)
+            (let ((l (split-char ch)))
+              (progn
+                ;; Unicode 0x0E00-0x0E7F is Thai. Transform back to TIS620
+                (setq ch2 (nth 2 l)
+                      ch3 (nth 3 l))
+                (if (and (eq ch2 14) (< ch3 128))
+                    (setq charset 'thai-tis620
+                          ch (encode-char ch 'thai-tis620))))))
+
+        ;; `split-char' in emacs 23+ is sensitive to charset priority.
+        (cond ((> emacs-major-version 22)
+               (if (not (eq charset 'ascii))
+                   (set-charset-priority charset))))
+
         (if (eq charset 'ascii)
             ;; Not a multibyte character.
             (progn
@@ -623,8 +695,9 @@
           ;;   CH1 -- first character code
           ;;   CH2 -- second character code (of two-byte characters)
           ;;          if any
-          (if (or (eq charset 'chinese-big5-1)
-                  (eq charset 'chinese-big5-2))
+          (if (or (eq charset 'big5)
+                  (or (eq charset 'chinese-big5-1)
+                      (eq charset 'chinese-big5-2)))
               ;; Emacs uses two special character sets for Big5
               ;; characters.  We must decode the current character to
               ;; get the real Big5 character code.
@@ -650,8 +723,14 @@
           ;; FORMAT-SPEC tells how to encode this character.
           (setq format-spec (cdr (assq charset cjk-format-spec-table)))
           (if (null format-spec)
-              ;; Unsupported character set.  Do nothing.
-              nil
+              ;; Unsupported character set.
+              (when (not unsupported-charset-warned)
+                (let ((coding-system-for-write (terminal-coding-system)))
+                  (message "WARNING: Detected unsupported character set %s"
+                           charset)
+                  (message "Consider using \`coding:\' or setting LANG."))
+                ;; Suppress further warning in the same lang block.
+                (setq unsupported-charset-warned t))
             ;; Ok, it is supported.  If this character set is a CJK
             ;; character set (i.e., it is in CJK-ENC-TABLE), we need a
             ;; special header at the beginning of the output file.
@@ -703,6 +782,9 @@
                   (re-search-forward "\\ct+" nil t)
                   (setq end (point-marker))
                   (goto-char start)
+                  ;; THAI-BREAK-WORDS is in `thai-word.el',
+                  ;; shipped with emacs 22+ onwards.
+                  ;; loads from cjk for emacs 21 or below.
                   (thai-break-words "|" end)
                   ;; Extract this run.
                   (setq str (buffer-substring start end)
@@ -817,8 +899,9 @@
         (if (> (- (point) last-pos) 1000)
             (progn
               (setq last-pos (point))
-              (message "Converting: %2d%%"
-                       (/ (* 100 (point)) (point-max)))))
+              (let ((coding-system-for-write (terminal-coding-system)))
+                (message "Converting: %2d%%"
+                         (/ (* 100 (point)) (point-max))))))
 
         ;; Advance to the next character and loop.
         (forward-char 1))
