@@ -7,13 +7,13 @@
 #
 # Call the script as
 #
-#   perl clonevf.pl tfm_name vf_name
+#   perl clonevf.pl tfm-name vf-name
 #
 # Example:
 #
 #   perl clonevf.pl bsmiuv bsmilpv
 
-# Copyright (C) 1994-2006  Werner Lemberg <wl@gnu.org>
+# Copyright (C) 1994-2021  Werner Lemberg <wl@gnu.org>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -36,7 +36,7 @@ my $prog = $0;
 $prog =~ s@.*/@@;
 
 if ($#ARGV != 1) {
-  die("usage: $prog tfm_name vf_name\n");
+  die("usage: $prog tfm-name vf-name\n");
 }
 
 my $tfmname = $ARGV[0];
