@@ -9,10 +9,10 @@
 #
 # Call the script as
 #
-#   perl sfd2uni.pl sfd_file namestem uni_namestem codingscheme
+#   perl sfd2uni.pl sfd-file namestem uni-namestem codingscheme
 #
-# `sfd_file' is the subfont definition file, `namestem' is the name stem
-# of the subfonts defined in `sfd_file', and `uni_namestem' holds the prefix
+# `sfd-file' is the subfont definition file, `namestem' is the name stem
+# of the subfonts defined in `sfd-file', and `uni-namestem' holds the prefix
 # for the Unicode subfonts. `codingscheme' (converted to uppercase) is used
 # for the CODINGSCHEME parameter in the resulting TFM files.
 #
@@ -26,7 +26,7 @@
 # A collection of useful subfont definition files for CJK fonts can be found
 # in the ttf2pk package.
 
-# Copyright (C) 1994-2006  Werner Lemberg <wl@gnu.org>
+# Copyright (C) 1994-2021  Werner Lemberg <wl@gnu.org>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -49,7 +49,7 @@ my $prog = $0;
 $prog =~ s@.*/@@;
 
 if ($#ARGV != 3) {
-  die("usage: $prog sfd_file namestem uni_namestem codingscheme\n");
+  die("usage: $prog sfd-file namestem uni-namestem codingscheme\n");
 }
 
 my $sfdfile = $ARGV[0];
